API docs for “spamfighter.plugins.sample_domain_provider.SampleDomainProvider”

# Class s.p.s.SampleDomainProvider(object):

Part of spamfighter.plugins.sample_domain_provider View Source View In Hierarchy

Провайдер статического дефолтного домена.

Method | __init__ | Конструктор.
Method | name | Получить имя плагина.
Method | getDefaultDomain | Получить домен по умолчанию в системе.

def __init__(self): (source)
Конструктор.

def name(self): (source)
Получить имя плагина.

Returns | имя плагина (type: `str` )

def getDefaultDomain(self): (source)
Получить домен по умолчанию в системе.

Returns | домен по умолчанию. (type: `spamfighter.interfaces.IDomain` )